stringtools.arg_to_bidirectional_lilypond_symbol
================================================

.. autofunction:: abjad.tools.stringtools.arg_to_bidirectional_lilypond_symbol.arg_to_bidirectional_lilypond_symbol
